<template>
  <j-modal
    :title="title"
    :width="800"
    :visible="visible"
    :confirmLoading="confirmLoading"
    switchFullscreen
    @ok="handleOk"
    @cancel="handleCancel"
    cancelText="关闭">

    <a-spin :spinning="confirmLoading">
      <a-form-model ref="form" :model="model" :rules="validatorRules">
        <a-form-model-item :labelCol="labelCol" :wrapperCol="wrapperCol" prop="hfCode" label="HF编码">
          <a-input placeholder="请输入HF编码" v-model="model.hfCode" />
        </a-form-model-item>
        <a-form-model-item :labelCol="labelCol" :wrapperCol="wrapperCol" prop="hfName" label="模板名称">
          <a-input placeholder="请输入模板名称" v-model="model.hfName" />
        </a-form-model-item>
        <a-form-model-item :labelCol="labelCol" :wrapperCol="wrapperCol" prop="hfCategory" label="模板分类">
          <j-dict-select-tag dict-code="hf_template_category" placeholder="请选择模板分类" :disabled="editable"
                             v-model="model.hfCategory"></j-dict-select-tag>
        </a-form-model-item>
      </a-form-model>
    </a-spin>
  </j-modal>
</template>

<script>
import { httpAction } from '@/api/manage'
import moment from 'moment'

export default {
  name: 'EamBaseHFCodeModal',
  data() {
    return {
      title: '操作',
      visible: false,
      model: {},
      editable: false,
      upgradeFlag: false,
      labelCol: {
        xs: { span: 24 },
        sm: { span: 5 }
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 }
      },

      confirmLoading: false,
      validatorRules: {
        hfCode:[
          { required: true, message: '请输入HF编码!' }
        ],
        hfName: [
          { required: true, message: '请输入模板名称!' }
        ],
        hfCategory: [
          { required: true, message: '请选择模板分类!' }
        ],
      },
      url: {
        add: '/eam/eamBaseHFCode/add',
        edit: '/eam/eamBaseHFCode/edit',
        upgrade: '/eam/eamBaseHFCode/upgrade',
      }
    }
  },
  created() {
  },
  methods: {
    add() {
      //初始化默认值
      this.model = {};
      this.visible = true;
      this.editable = false;
      this.upgradeFlag = false;
    },
    edit(record) {
      this.model = Object.assign({}, record);
      this.visible = true;
      this.editable = true;
      this.upgradeFlag = false;
    },
    upgrade(record) {
      this.model = Object.assign({}, record);
      this.visible = true;
      this.editable = true;
      this.upgradeFlag = true;
    },
    close() {
      this.$emit('close')
      this.visible = false
      this.$refs.form.clearValidate()
    },
    handleOk() {
      const that = this
      // 触发表单验证
      this.$refs.form.validate(valid => {
        if (valid) {
          that.confirmLoading = true
          let httpurl = ''
          let method = ''
          if (!this.model.id) {
            httpurl += this.url.add
            method = 'post'
          } else {
            if(this.upgradeFlag) {
              httpurl+=this.url.upgrade;
            }else {
              httpurl+=this.url.edit;
            }
            method = 'put';
          }
          httpAction(httpurl, this.model, method).then((res) => {
            if (res.success) {
              that.$message.success(res.message)
              that.$emit('ok')
              that.close();
            } else {
              that.$message.warning(res.message)
            }
          }).finally(() => {
            that.confirmLoading = false
          })
        } else {
          return false
        }
      })
    },
    handleCancel() {
      this.close()
    }


  }
}
</script>

<style lang="less" scoped>

</style>